@@ -1,4 +1,4 @@
-/* Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -237,6 +237,7 @@
 #define SHAREDIR "/usr/share/mysql"
 #define DEFAULT_BASEDIR "/usr"
 #define MYSQL_DATADIR "/var/lib/mysql"
+#define MYSQL_KEYRINGDIR "/usr/keyring"
 #define DEFAULT_CHARSET_HOME "/usr"
 #define PLUGINDIR "/usr/lib/mysql/plugin"
 #define DEFAULT_SYSCONFDIR "/etc/mysql"
@@ -249,7 +250,8 @@
 #define INSTALL_INCLUDEDIR "/usr/local/mysql/include/perconaserver"
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.10-3/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.10-3/plugin/scalability_metrics/tests;/build/percona-server/src/percona-server-5.7.10-3/plugin/audit_log/tests"
+#define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.11-4/plugin/scalability_metrics/tests;/build/percona-server/src/percona-server-5.7.11-4/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.11-4/plugin/audit_log/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
@@ -383,15 +385,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 10
-#define MYSQL_VERSION_EXTRA "-3"
+#define MYSQL_VERSION_PATCH 11
+#define MYSQL_VERSION_EXTRA "-4"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.10-3"
+#define PACKAGE_STRING "MySQL Server 5.7.11-4"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.10-3"
-#define VERSION "5.7.10-3"
+#define PACKAGE_VERSION "5.7.11-4"
+#define VERSION "5.7.11-4"
 #define PROTOCOL_VERSION 10
 
 /*
@@ -434,4 +436,7 @@
 #define DEFAULT_SECURE_FILE_PRIV_EMBEDDED_DIR "NULL"
 /* #undef HAVE_LIBNUMA */
 
+/* For default value of --early_plugin_load */
+#define DEFAULT_EARLY_PLUGIN_LOAD "keyring_file=keyring_file.so"
+
 #endif
